@@ -452,6 +452,7 @@ class ReferentialIntegrityPlugin(Plugin):
             if delay is not None and delay != 0:
                 report = copy.deepcopy(DSRILE0001)
                 report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
+                report['check'] = f'refint:update_delay'
                 yield report
 
     def _lint_attr_indexes(self):
@@ -488,6 +489,7 @@ class ReferentialIntegrityPlugin(Plugin):
                             report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
                             report['items'].append(suffix)
                             report['items'].append(attr)
+                            report['check'] = f'refint:attr_indexes'
                             yield report
                     except:
                         # No index at all, bad
@@ -498,6 +500,7 @@ class ReferentialIntegrityPlugin(Plugin):
                         report['fix'] = report['fix'].replace('YOUR_INSTANCE', self._instance.serverid)
                         report['items'].append(suffix)
                         report['items'].append(attr)
+                        report['check'] = f'refint:attr_indexes'
                         yield report
 
     def get_update_delay(self):
@@ -515,6 +518,21 @@ class ReferentialIntegrityPlugin(Plugin):
 
         self.set('referint-update-delay', str(value))
 
+    def get_log_file(self):
+        """Get referint log file"""
+
+        return self.get_attr_val_utf8('referint-logfile')
+
+    def get_log_file_formatted(self):
+        """Get referint log file"""
+
+        return self.display_attr('referint-logfile')
+
+    def set_log_file(self, value):
+        """Set referint log file"""
+
+        self.set('referint-logfile', value)
+
     def get_membership_attr(self, formatted=False):
         """Get referint-membership-attr attribute"""
 
@@ -1881,7 +1899,7 @@ class AccountPolicyEntry(DSLdapObject):
     """
 
     def __init__(self, instance, dn=None):
-        super(AccountPolicyConfig, self).__init__(instance, dn)
+        super(AccountPolicyEntry, self).__init__(instance, dn)
         self._rdn_attribute = 'cn'
         self._must_attributes = ['cn']
         self._create_objectclasses = ['top', 'accountpolicy']
